Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenkernel/BKE_library_remap.h')
-rw-r--r--source/blender/blenkernel/BKE_library_remap.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenkernel/BKE_library_remap.h b/source/blender/blenkernel/BKE_library_remap.h
index 41ac8c8c8e6..d51bc5c2bce 100644
--- a/source/blender/blenkernel/BKE_library_remap.h
+++ b/source/blender/blenkernel/BKE_library_remap.h
@@ -61,8 +61,8 @@ enum {
* is also performed. Usual nightmare...
*/
ID_REMAP_NO_INDIRECT_PROXY_DATA_USAGE = 1 << 4,
- /** Do not remap static override pointers. */
- ID_REMAP_SKIP_STATIC_OVERRIDE = 1 << 5,
+ /** Do not remap library override pointers. */
+ ID_REMAP_SKIP_OVERRIDE_LIBRARY = 1 << 5,
};
/* Note: Requiring new_id to be non-null, this *may* not be the case ultimately,